@@ -7,6 +7,7 @@ class Adapter_For_MAM(Basic_Adapter):
     """
     transformer_dict = {
         "Tnr": "tnr",
+        "tnr_rechtefluss":"tnr_rechtefluss",
         "tnr2": "tnr",
         "d_id": "did",
         "Status_TP": "status",
@@ -81,9 +82,11 @@ class Adapter_For_MAM(Basic_Adapter):
         "deal_type": "deal_type",
     }
     metadata_dict = {
+        "VendorID": "vendor_id",
         'IMDBlink': 'imdb_link',
         'ISAN': 'isan',
         'EIDR': 'eidr',
         'Titel': 'titel_local',
         'Originaltitel': 'titel_ov',
+        'trailer_link': 'trailer_link',
     }
